@@ -45,34 +45,34 @@ class ActionConfigurationAction(workflows.Action):
         required=True)
 
     backup_name = forms.CharField(
-        label=_("Job Name"),
+        label=_("Action Name *"),
         required=False)
 
     mysql_conf = forms.CharField(
-        label=_("MySQL Configuration File"),
+        label=_("MySQL Configuration File *"),
         help_text=_("Set the path where the MySQL configuration file "
                     "is on the file system "),
         required=False)
 
     sql_server_conf = forms.CharField(
-        label=_("SQL Server Configuration File"),
+        label=_("SQL Server Configuration File *"),
         help_text=_("Set the path where the SQL Server configuration file"
                     " is on the file system"),
         required=False)
 
     path_to_backup = forms.CharField(
-        label=_("Source File/Directory"),
+        label=_("Source File/Directory *"),
         help_text=_("The file or directory you want to back up."),
         required=False)
 
     container = forms.CharField(
-        label=_("Container Name or Path"),
+        label=_("Container Name or Path *"),
         help_text=_("Swift container for swift backend or "
                     "path for ssh or local backend"),
         required=False)
 
     restore_abs_path = forms.CharField(
-        label=_("Restore Absolute Path"),
+        label=_("Restore Absolute Path *"),
         help_text=_("Set the absolute path where you"
                     " want your data restored."),
         required=False)
@@ -99,12 +99,12 @@ class ActionConfigurationAction(workflows.Action):
         required=False)
 
     cinder_vol_id = forms.CharField(
-        label=_("Cinder Volume ID"),
+        label=_("Cinder Volume ID *"),
         help_text=_("Id of cinder volume for backup"),
         required=False)
 
     nova_inst_id = forms.CharField(
-        label=_("Nova Volume ID"),
+        label=_("Nova Volume ID *"),
         help_text=_("Id of nova instance for backup"),
         required=False)
 
@@ -141,17 +141,17 @@ class ActionConfigurationAction(workflows.Action):
         required=False)
 
     ssh_key = forms.CharField(
-        label=_("SSH Private Key"),
+        label=_("SSH Private Key *"),
         help_text=_("Path for ssh private key"),
         required=False)
 
     ssh_username = forms.CharField(
-        label=_("SSH Username"),
+        label=_("SSH Username *"),
         help_text=_("Path for ssh private key"),
         required=False)
 
     ssh_host = forms.CharField(
-        label=_("SSH Host"),
+        label=_("SSH Host *"),
         help_text=_("IP address or dns name of host to connect through ssh"),
         required=False)
 
@@ -159,6 +159,12 @@ class ActionConfigurationAction(workflows.Action):
         cleaned_data = super(ActionConfigurationAction, self).clean()
 
         if cleaned_data.get('action') == 'backup':
+            if cleaned_data.get('mode') == 'cinder' \
+                    or cleaned_data.get('mode') == 'nova':
+                self._check_container(cleaned_data)
+                self._check_backup_name(cleaned_data)
+                return cleaned_data
+
             self._check_container(cleaned_data)
             self._check_backup_name(cleaned_data)
             self._check_path_to_backup(cleaned_data)
@@ -177,12 +183,12 @@ class ActionConfigurationAction(workflows.Action):
 
     def _check_container(self, cleaned_data):
         if not cleaned_data.get('container'):
-            msg = _("You must define a container.")
+            msg = _("You must define a container or path to backup.")
             self._errors['container'] = self.error_class([msg])
 
     def _check_backup_name(self, cleaned_data):
         if not cleaned_data.get('backup_name'):
-            msg = _("You must define an backup name.")
+            msg = _("You must define an action name.")
             self._errors['backup_name'] = self.error_class([msg])
 
     def _check_path_to_backup(self, cleaned_data):
@@ -202,7 +208,6 @@ class ActionConfigurationAction(workflows.Action):
 
     def populate_action_choices(self, request, context):
         return [
-            ('', _("Select an action")),
             ('backup', _("Backup")),
             ('restore', _("Restore")),
             ('admin', _("Admin")),
@@ -253,7 +258,7 @@ class ActionConfiguration(workflows.Step):
 
 
 class SnapshotConfigurationAction(workflows.Action):
-    use_snapshot = forms.BooleanField(
+    snapshot = forms.BooleanField(
         label=_("Snapshot"),
         help_text=_("Use a LVM or Shadow Copy snapshot "
                     "to have point in time consistent backups"),
@@ -261,53 +266,6 @@ class SnapshotConfigurationAction(workflows.Action):
         initial=False,
         required=False)
 
-    is_windows = forms.BooleanField(
-        label=_("Job For Windows"),
-        help_text=_("Is this job going to "
-                    "execute on windows?"),
-        widget=forms.CheckboxInput(),
-        required=False)
-
-    lvm_auto_snap = forms.CharField(
-        label=_("LVM Auto Snapshot"),
-        help_text=_("Automatically guess the volume group and "
-                    "volume name for given PATH."),
-        required=False)
-
-    lvm_srcvol = forms.CharField(
-        label=_("Set The Volume For Snapshot"),
-        help_text=_("Set the lvm volume you want to take a "
-                    "snapshot from. Default no volume"),
-        required=False)
-
-    lvm_snapname = forms.CharField(
-        label=_("Set A Snapshot Name"),
-        help_text=_("Set the lvm snapshot name to use. "
-                    "If the snapshot name already exists, "
-                    "the old one will be used a no new one "
-                    "will be created. Default freezer_backup_snap."),
-        required=False)
-
-    lvm_snapsize = forms.CharField(
-        label=_("Snapshot Size"),
-        help_text=_("Set the lvm snapshot size when creating "
-                    "a new snapshot. Please add G for Gigabytes "
-                    "or M for Megabytes, i.e. 500M or 8G. Default 5G."),
-        required=False)
-
-    lvm_dirmount = forms.CharField(
-        label=_("Snapshot Directory"),
-        help_text=_("Set the directory you want to mount "
-                    "the lvm snapshot to. Default not set"),
-        required=False)
-
-    lvm_volgroup = forms.CharField(
-        label=_("Volume Group"),
-        help_text=_("Specify the volume group of your logical volume."
-                    "This is important to mount your snapshot volume."
-                    "Default not set"),
-        required=False)
-
     class Meta(object):
         name = _("Snapshot")
         help_text_template = "disaster_recovery/jobs" \
@@ -316,14 +274,7 @@ class SnapshotConfigurationAction(workflows.Action):
 
 class SnapshotConfiguration(workflows.Step):
     action_class = SnapshotConfigurationAction
-    contributes = ('use_snapshot',
-                   'is_windows',
-                   'lvm_auto_snap',
-                   'lvm_srcvol',
-                   'lvm_snapname',
-                   'lvm_snapsize',
-                   'lvm_dirmount',
-                   'lvm_volgroup',)
+    contributes = ('snapshot',)
 
 
 class AdvancedConfigurationAction(workflows.Action):
@@ -526,7 +477,7 @@ class AdvancedConfiguration(workflows.Step):
                    'dereference_symlink',
                    'dry_run',
                    'max_priority',
-                   'quiet',)
+                   'quiet')
 
 
 class RulesConfigurationAction(workflows.Action):
@@ -580,20 +531,6 @@ class ActionWorkflow(workflows.Workflow):
 
     def handle(self, request, context):
         try:
-            if context['is_windows']:
-                client_os = 'Windows'
-                context.pop('is_windows')
-            else:
-                client_os = 'Linux'
-                context.pop('is_windows')
-
-            if context['use_snapshot'] and client_os == 'Windows':
-                context['vssadmin'] = True
-                context.pop('use_snapshot')
-            else:
-                context['vssadmin'] = False
-                context.pop('use_snapshot')
-
             if context['action_id'] == '':
                 freezer_api.Action(request).create(context)
             else:
