@@ -30,10 +30,24 @@ LOG = logging.getLogger(__name__)
 def client(request):
     """Return a freezer client object"""
     api_url = _get_service_url(request)
-    return freezer.apiclient.client.Client(
-        token=request.user.token.id,
-        auth_url=getattr(settings, 'OPENSTACK_KEYSTONE_URL'),
-        endpoint=api_url)
+
+    # get keystone version to connect to
+    ks_version = getattr(settings,
+                         'OPENSTACK_API_VERSIONS', {}).get('identity', 2.0)
+
+    credentials = {
+        'token': request.user.token.id,
+        'auth_url': getattr(settings, 'OPENSTACK_KEYSTONE_URL'),
+        'endpoint': api_url,
+        'version': ks_version
+    }
+
+    if ks_version == 3:
+        credentials['project_name'] = request.user.project_name
+        credentials['project_domain_name'] = \
+            request.user.domain_name or 'Default'
+
+    return freezer.apiclient.client.Client(**credentials)
 
 
 @memoized
@@ -87,6 +101,7 @@ class Job(object):
             job.get('description'),
             job.get('job_schedule', {}).get('result'),
             job.get('job_schedule', {}).get('event'),
+            job.get('client_id')
         ) for job in jobs]
 
     def get(self, job_id, json=False):
@@ -99,7 +114,8 @@ class Job(object):
             job.get('job_id'),
             job.get('description'),
             job.get('job_schedule', {}).get('result'),
-            job.get('job_schedule', {}).get('event'))
+            job.get('job_schedule', {}).get('event'),
+            job.get('client_id'))
 
     def create(self, job):
         return self._build(job)
@@ -289,14 +305,18 @@ class Session(object):
     def jobs(self, session_id):
         session = self.get(session_id, json=True)
         jobs = []
+
+        if session is None:
+            return jobs
+
         try:
             jobs = [utils.JobsInSessionObject(k,
                                               session_id,
                                               v['client_id'],
                                               v['result'])
                     for k, v in session['jobs'].iteritems()]
-        except AttributeError:
-            pass
+        except AttributeError as error:
+            LOG.error(error.message)
         return jobs
 
     def _build(self, session):
@@ -334,6 +354,7 @@ class Action(object):
             action['freezer_action'].get('path_to_backup')
             or action['freezer_action'].get('restore_abs_path'),
             action['freezer_action'].get('storage'),
+            mode=action['freezer_action'].get('mode')
         ) for action in actions]
 
     def get(self, job_id, json=False):
@@ -388,7 +409,13 @@ class Action(object):
         utils.assign_and_remove(action, action_rules, 'max_retries_interval')
         utils.assign_and_remove(action, action_rules, 'mandatory')
         action = utils.create_dict(**action)
+        action.pop('action_id', None)
+        # if the backup name has spaces the tar metadata file cannot be found
+        # so we replace " " for "_"
+        backup_name = action.pop('backup_name', None)
+        action['backup_name'] = backup_name.replace(' ', '_')
         action = {'freezer_action': action}
+        action.update(action_rules)
         return self.client.actions.create(action)
 
 
@@ -463,6 +490,12 @@ class Backup(object):
             total_broken_links=b.get('backup_metadata', {}).get(
                 'total_broken_links'),
             excluded_files=b.get('backup_metadata', {}).get('excluded_files'),
+            storage=b.get('backup_metadata', {}).get('storage'),
+            ssh_host=b.get('backup_metadata', {}).get('ssh_host'),
+            ssh_key=b.get('backup_metadata', {}).get('ssh_key'),
+            ssh_username=b.get('backup_metadata', {}).get('ssh_username'),
+            ssh_port=b.get('backup_metadata', {}).get('ssh_port'),
+            mode=b.get('backup_metadata', {}).get('ssh_mode'),
         ) for b in backups]
 
     def get(self, backup_id, json=False):
@@ -491,22 +524,37 @@ class Backup(object):
             total_broken_links=b.get('backup_metadata', {}).get(
                 'total_broken_links'),
             excluded_files=b.get('backup_metadata', {}).get('excluded_files'),
+            storage=b.get('backup_metadata', {}).get('storage'),
+            ssh_host=b.get('backup_metadata', {}).get('ssh_host'),
+            ssh_key=b.get('backup_metadata', {}).get('ssh_key'),
+            ssh_username=b.get('backup_metadata', {}).get('ssh_username'),
+            ssh_port=b.get('backup_metadata', {}).get('ssh_port'),
+            mode=b.get('backup_metadata', {}).get('ssh_mode'),
         )
 
     def restore(self, data):
         backup = self.get(data['backup_id'])
         client_id = data['client']
-        name = "Restore job for {0}".format(client_id)
-        # TODO(m3m0): change storage to be flexible
+        name = "Restore {0} for {1}".format(backup.backup_name, client_id)
+
+        iso_date = utils.timestamp_to_iso(backup.time_stamp)
+
         action = {
             'action': 'restore',
             'backup_name': backup.backup_name,
             'restore_abs_path': data['path'],
             'container': backup.container,
             'restore_from_host': backup.hostname,
-            'storage': 'local'
+            'storage': backup.storage,
+            'restore_from_date': iso_date
         }
 
+        if backup.storage == 'ssh':
+            action['ssh_host'] = backup.ssh_host
+            action['ssh_key'] = backup.ssh_key
+            action['ssh_username'] = backup.ssh_username
+            action['ssh_port'] = backup.ssh_port
+
         action_id = Action(self.request).create(action)
 
         job = {
